@@ -111,18 +111,6 @@ class URLTarget(object):
         url_parts[4] = urlparse.urlencode(query)
         return urlparse.urlunparse(url_parts)
 
-    def _extend_sciebo_url(self, url: str) -> str:
-        """
-            Adds the string /download to a URL containing 'sciebo.de'
-            @param url: The URL where the string should be added.
-            @return: The URL with the string.
-        """
-        if 'sciebo.de' in url and 'download' not in url:
-            url_parts = list(urlparse.urlparse(url))
-            url_parts[2] = url_parts[2].strip('/') + '/download'
-            url = urlparse.urlunparse(url_parts)
-        return url
-
     def create_dir(self, path: str):
         # Creates the folders of a path if they do not exist.
         if not os.path.exists(path):
@@ -269,8 +257,14 @@ class URLTarget(object):
 
     def yt_hook(self, d):
         downloaded_bytes = d.get('downloaded_bytes', 0)
+        if downloaded_bytes is None:
+            downloaded_bytes = 0
         total_bytes_estimate = d.get('total_bytes_estimate', 0)
+        if total_bytes_estimate is None:
+            total_bytes_estimate = 0
         total_bytes = d.get('total_bytes', 0)
+        if total_bytes is None:
+            total_bytes = 0
 
         difference = downloaded_bytes - self.downloaded
         self.thread_report[self.thread_id]['total'] += difference
@@ -312,6 +306,7 @@ class URLTarget(object):
     def is_blocked_for_youtube_dl(self, url_to_download: str):
         url_parsed = urlparse.urlparse(url_to_download)
         if url_parsed.hostname.endswith('youtube.com') and url_parsed.path.startswith('/channel/'):
+            # We do not want to download whole channels
             return True
         return False
 
@@ -345,11 +340,11 @@ class URLTarget(object):
 
         Args:
             add_token (bool, optional): Adds the ws-token to the url. Defaults to False.
-            delete_if_successful (bool, optional): Deletes the tmp file if download was successfull. Defaults to False.
+            delete_if_successful (bool, optional): Deletes the tmp file if download was successful. Defaults to False.
             use_cookies (bool, optional): Adds the cookies to the requests. Defaults to False.
 
         Returns:
-            bool: If it was successfull.
+            bool: If it was successful.
         """
 
         url_to_download = self.file.content_fileurl
@@ -358,9 +353,6 @@ class URLTarget(object):
         if add_token:
             url_to_download = self._add_token_to_url(self.file.content_fileurl)
 
-        # adds /download to sciebo.de urls
-        url_to_download = self._extend_sciebo_url(self.file.content_fileurl)
-
         cookies_path = self.options.get('cookies_path', None)
         if use_cookies:
             if cookies_path is None or not os.path.isfile(cookies_path):
@@ -466,23 +458,43 @@ class URLTarget(object):
 
             ydl = youtube_dl.YoutubeDL(ydl_opts)
             add_additional_extractors(ydl)
-            try:
-                ydl_results = ydl.download([url_to_download])
-                if ydl_results == 1:
-                    pass
-                elif self.file.module_name != 'index_mod-page':
-                    self.file.saved_to = str(Path(self.destination) / self.filename)
-                    self.file.time_stamp = int(time.time())
 
-                    self.success = True
-                    return True
-            except Exception as e:
-                logging.error(
-                    'T%s - Youtube-dl failed! Error: %s',
-                    self.thread_id,
-                    e,
-                )
-                self.youtube_dl_failed_with_error = True
+            videopasswords = self.options.get('videopasswords', {})
+
+            password_list = videopasswords.get(url_parsed.netloc, [])
+            if not type(password_list) is list:
+                password_list = [password_list]
+
+            idx_pw = 0
+            while True:
+                if idx_pw + 1 <= len(password_list):
+                    ydl.params['videopassword'] = password_list[idx_pw]
+
+                self.youtube_dl_failed_with_error = False
+                # we restart youtube-dl, so we need to reset the return code
+                ydl._download_retcode = 0
+                try:
+                    ydl_results = ydl.download([url_to_download])
+                    if ydl_results == 1:
+                        pass
+                    elif self.file.module_name != 'index_mod-page':
+                        self.file.saved_to = str(Path(self.destination) / self.filename)
+                        self.file.time_stamp = int(time.time())
+
+                        self.success = True
+                        return True
+                    else:
+                        break
+                except Exception as e:
+                    logging.error(
+                        'T%s - Youtube-dl failed! Error: %s',
+                        self.thread_id,
+                        e,
+                    )
+                    self.youtube_dl_failed_with_error = True
+                idx_pw += 1
+                if idx_pw + 1 > len(password_list):
+                    break
 
             # if we want we could save ydl.cookiejar (Also the cookiejar of moodle-dl)
 
@@ -686,7 +698,7 @@ class URLTarget(object):
                 logging.warning('T%s - Moving the old file %s failed!  Error: %s', self.thread_id, old_path, e)
 
             self.fs_lock.release()
-        except Exception:
+        except Exception as e:
             logging.warning('T%s - Moving the old file %s failed unexpectedly!  Error: %s', self.thread_id, old_path, e)
 
         return False
@@ -744,7 +756,7 @@ class URLTarget(object):
                 if self.try_move_file():
                     return self.success
 
-            # if it is a Description we have to create a descripton file
+            # if it is a Description we have to create a description file
             # instead of downloading it
             if self.file.content_type == 'description':
                 self.create_description()
@@ -753,12 +765,12 @@ class URLTarget(object):
             add_token = True
             if self.file.module_modname.startswith('index_mod'):
                 add_token = True
-                self.try_download_link(add_token, True, False)
+                self.try_download_link(add_token, delete_if_successful=True, use_cookies=False)
                 return self.success
 
             if self.file.module_modname.startswith('cookie_mod'):
                 add_token = False
-                self.try_download_link(add_token, True, True)
+                self.try_download_link(add_token, delete_if_successful=True, use_cookies=True)
                 return self.success
 
             # if it is a URL we have to create a shortcut
