@@ -1,8 +1,10 @@
 import re
+import html
 import logging
 import hashlib
 import urllib.parse as urlparse
 
+
 from moodle_dl.state_recorder.file import File
 from moodle_dl.moodle_connector.request_helper import RequestHelper
 
@@ -80,16 +82,16 @@ class ResultsHandler:
             if module_modname in ['moodecvideo', 'page']:
                 module_modname = 'index_mod-' + module_modname
 
-            if module_modname in ['kalvidres']:
-                module_modname = 'cookie_mod-' + module_modname
-                files += self._handle_cookie_mod(section_name, module_name, module_modname, module_id, module_url)
-
             if module_description is not None:
                 files += self._handle_description(
                     section_name, module_name, module_modname, module_id, module_description
                 )
 
-            if module_modname.startswith(('resource', 'folder', 'url', 'index_mod')):
+            if module_modname in ['kalvidres', 'helixmedia', 'lti']:
+                module_modname = 'cookie_mod-' + module_modname
+                files += self._handle_cookie_mod(section_name, module_name, module_modname, module_id, module_url)
+
+            elif module_modname.startswith(('resource', 'folder', 'url', 'index_mod')):
                 files += self._handle_files(section_name, module_name, module_modname, module_id, module_contents)
 
             elif module_modname == 'assign':
@@ -113,6 +115,8 @@ class ResultsHandler:
                 forums_files = forums.get('files', [])
 
                 files += self._handle_files(section_name, module_name, module_modname, module_id, forums_files)
+            else:
+                logging.debug('Got unhandled module: name=%s mod=%s url=%s', module_name, module_modname, module_url)
 
         return files
 
@@ -128,8 +132,27 @@ class ResultsHandler:
         if not isinstance(description, str):
             return description
 
+        # to avoid changing encodings (see issue #96) we unencode and unquote everything
+        description = html.unescape(description)
+        description = urlparse.unquote(description)
+
+        # ids can change very quickly
         description = re.sub(r'id="[^"]*"', "", description)
         description = re.sub(r"id='[^']*'", "", description)
+
+        # Embedded images from Moodle can change their timestemp (is such a theme feature)
+        # We change every timestemp to -1 the default.
+        description = re.sub(
+            r"\/theme\/image.php\/(\w+)\/(\w+)\/\d+\/",
+            r"/theme/image.php/\g<1>/\g<2>/-1/",
+            description,
+        )
+
+        # some folder downloads inside a description file may have some session key inside which will always be different.
+        # remove it, to prevent always tagging this file as "modified".
+        description = re.sub(r'<input type="hidden" name="sesskey" value="[0-9a-zA-Z]*" \/>', "", description)
+        description = re.sub(r"<input type='hidden' name='sesskey' value='[0-9a-zA-Z]*' \/>", "", description)
+
         return description
 
     def _find_all_urls_in_description(
@@ -155,7 +178,9 @@ class ResultsHandler:
         """
 
         urls = list(set(re.findall(r'href=[\'"]?([^\'" >]+)', description)))
+        urls += list(set(re.findall(r'<a[^>]*>([^<]*)<\/a>', description)))
         urls += list(set(re.findall(r'src=[\'"]?([^\'" >]+)', description)))
+        urls = list(set(urls))
 
         result = []
         original_module_modname = module_modname
@@ -164,9 +189,21 @@ class ResultsHandler:
             if url == '':
                 continue
 
-            module_modname = 'url-description-' + original_module_modname
+            # To avoid different encodings and quotes and so that youtube-dl downloads correctly
+            # (See issues #96 and #103), we remove all encodings.
+            url = html.unescape(url)
+            url = urlparse.unquote(url)
 
             url_parts = urlparse.urlparse(url)
+            if url_parts.hostname == self.moodle_domain and url_parts.path.find('/theme/image.php/') >= 0:
+                url = re.sub(
+                    r"\/theme\/image.php\/(\w+)\/(\w+)\/\d+\/",
+                    r"/theme/image.php/\g<1>/\g<2>/-1/",
+                    url,
+                )
+
+            module_modname = 'url-description-' + original_module_modname
+
             if url_parts.hostname == self.moodle_domain and url_parts.path.find('/webservice/') >= 0:
                 module_modname = 'index_mod-description-' + original_module_modname
 
