@@ -2,6 +2,9 @@ from youtube_dl.YoutubeDL import YoutubeDL
 
 from moodle_dl.ydl_extractors.zoomus import ZoomUSIE
 from moodle_dl.ydl_extractors.opencast import OpencastIE, OpencastPlaylistIE
+from moodle_dl.ydl_extractors.helixmedia import Helixmedia
+from moodle_dl.ydl_extractors.owncloud import Owncloud
+from moodle_dl.ydl_extractors.opencast_lti import OpencastLTI
 
 
 def add_additional_extractors(ydl: YoutubeDL):
@@ -9,6 +12,9 @@ def add_additional_extractors(ydl: YoutubeDL):
         OpencastIE(ydl),
         OpencastPlaylistIE(ydl),
         ZoomUSIE(ydl),
+        Helixmedia(ydl),
+        Owncloud(ydl),
+        OpencastLTI(ydl),
     ]
 
     for extractor in additional_extractors:
